use crate::*;

pub fn rle_diff_horizontal(prev_frame: &Frame, frame: &Frame) -> EncodedFrame {
	let mut pixels = Vec::new();
	for y in 0..HEIGHT {
		for x in 0..WIDTH {
			pixels.push(frame[x][y] ^ prev_frame[x][y]);
		}
	}
	EncodedFrame {
		encoding: Encoding::RLEDiffHorizontal,
		data: rle_255_encode(&pixels),
	}
}

pub fn rle_diff_vertical(prev_frame: &Frame, frame: &Frame) -> EncodedFrame {
	let mut pixels = Vec::new();
	for x in 0..WIDTH {
		for y in 0..HEIGHT {
			pixels.push(frame[x][y] ^ prev_frame[x][y]);
		}
	}
	EncodedFrame {
		encoding: Encoding::RLEDiffVertical,
		data: rle_255_encode(&pixels),
	}
}

pub fn rle_horizontal(_prev_frame: &Frame, frame: &Frame) -> EncodedFrame {
	let mut pixels = Vec::new();
	for y in 0..HEIGHT {
		for x in 0..WIDTH {
			pixels.push(frame[x][y]);
		}
	}
	EncodedFrame {
		encoding: Encoding::RLEHorizontal,
		data: rle_255_encode(&pixels),
	}
}

pub fn rle_vertical(_prev_frame: &Frame, frame: &Frame) -> EncodedFrame {
	let mut pixels = Vec::new();
	for x in 0..WIDTH {
		for y in 0..HEIGHT {
			pixels.push(frame[x][y]);
		}
	}
	EncodedFrame {
		encoding: Encoding::RLEVertical,
		data: rle_255_encode(&pixels),
	}
}

pub fn fill_white(_prev_frame: &Frame, _frame: &Frame) -> EncodedFrame {
	EncodedFrame {
		encoding: Encoding::FillWhite,
		data: Vec::new(),
	}
}

pub fn fill_black(_prev_frame: &Frame, _frame: &Frame) -> EncodedFrame {
	EncodedFrame {
		encoding: Encoding::FillBlack,
		data: Vec::new(),
	}
}
